===================================
 Upstream Investment Opportunities
===================================

Many companies in the OpenStack community are looking to invest in upstream
development of OpenStack, for many reasons: to build expertise within the
organisation; to minimise the cost of downstream maintenance by addressing
issues at the source; to drive insights gained from serving their customers
into the upstream design; to mitigate business risks presented by a `tragedy of
the commons`_; or just to support the community. One study has shown that
companies that contribute to Open Source projects are able to capture up to
twice as much value from their use of the software than those who do not
contribute are.\ [#Nagle]_ However, OpenStack is a large project and figuring
out where best to invest to derive business value can seem daunting, especially
for those new to the community.

This page presents a curated set of suggested investment areas based on the
current opportunities available in the community, along with contact points for
each who can help you get started. The list is in no particular order - which
opportunity is the best fit depends on the nature of your business. In general,
contributors to the community need not be solely devoted to upstream
development, but we have found that long-term commitments generate the most
value for both the project and the sponsoring organisation.

Current Investment Opportunities
--------------------------------

.. toctree::
    :maxdepth: 2

    2022/index

Previous Investment Opportunities
---------------------------------

.. note::

    The "Investment Opportunities" process was introduced in 2019.
    The entries before (2018) are following our "Help Most Wanted list" format,
    which does not highlight business opportunities.

.. toctree::
    :maxdepth: 2

    2021/index
    2020/index
    2019/index
    2018/index

Inclusion Criteria
------------------

Only entries approved in the current calendar year are shown, but entries from
previous years may be reproposed if they are still relevant. Each item should
provide a business case that potential sponsors can use to identify whether the
opportunity is relevant to them, a description of the kind of experience needed
as well as the mentoring opportunities the community is able to provide, and at
least one point of contact for anyone interested in contributing.

.. _`tragedy of the commons`: https://en.wikipedia.org/wiki/Tragedy_of_the_commons

.. rubric:: Footnotes

.. [#Nagle]  Nagle, Frank, `Learning by Contributing: Gaining Competitive Advantage Through Contribution to Crowdsourced Public Goods <https://dx.doi.org/10.2139/ssrn.3091831>`_ (December 21, 2017).
